# -*- coding: utf-8 -*-
"""
Spyder Editor

This is a temporary script file.
"""

def say_hello(name = None):
    if name is None:
        return "Hello, World!"
    else:
        return f"Hello, {name}!"